@@ -1,4 +1,4 @@
-import pymysql, psycopg2, datetime, socket, configparser
+import pymysql, psycopg2, psycopg2.extras, datetime, socket, configparser
 
 host_ = socket.gethostbyname(socket.gethostname())
 port_ = 80 # Default XAMPP Apache server port.
@@ -58,6 +58,9 @@ def get_connection_object(conn):
     # PostgreSQL
     if (mode_ == "PostgreSQL"):
         if curs_ == "DICTIONARY":
+            print("lol")
+            return conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
+        else:
             return conn.cursor()
     # MySQL (by Default)
     else:
